.. _header:

Header
======

.. image:: ../_static/header.png

The header shows the hostname, OS name, release version, platform
architecture IP addresses (private and public) and system uptime.
Additionally, on GNU/Linux, it also shows the kernel version.

In client mode, the server connection status is also displayed.

If you are hosted on an AWS EC2 instance, some additional information
can be displayed (AMI-ID, region).  

**Connected**:

.. image:: ../_static/connected.png

**Disconnected**:

.. image:: ../_static/disconnected.png
